<?php

/**
 * @file imagefield_cycle.common.inc
 * This file contains functions common to the module and install file
 */

/**
 * Preset/default library path
 */
define('IMAGEFIELD_CYCLE_JQUERYCYCLE_PATH', 'sites/all/libraries/jquery.cycle');


/**
 * Dependency checker. This defines the JQuery Cycle path and a value to
 * determine whether or not it is present.
 */
function imagefield_cycle_dependency_check() {
  static $result = NULL;

  if (isset($result)) {
    return $result;
  }

  $filenames = array(
    'jquery.cycle.all.latest.min.js',
    'jquery.cycle.all.min.js',
  );

  $path = imagefield_cycle_get_path();
  foreach ($filenames as $filename) {
    $filepath = $path .'/'. $filename;
    if (is_file($filepath)) {
      break;
    }
  }

  $result = array(
    'path' => $path,
    'filepath' => $filepath,
    'exists' => (is_dir($path) && is_file($filepath)),
  );

  return $result;
}


/**
 * Code inspired by ColorBox
 */
function imagefield_cycle_get_path() {
  static $library_path = NULL;

  // Try to locate the library path in any possible setup.
  if ($library_path == NULL) {
    // First check the default location.
    $path = variable_get('imagfield_cycle_jquerycycle_path', IMAGEFIELD_CYCLE_JQUERYCYCLE_PATH);
    if (is_dir($path .'/jquery.cycle')) {
      $library_path = $path;
    }
    // Ask the libraries module as a fallback.
    elseif ($library_path == NULL && module_exists('libraries')) {
      if ($path = module_invoke('libraries', 'get_path', 'jquery.cycle')) {
        $library_path = $path;
        variable_set('imagfield_cycle_jquerycycle_path', $library_path);
      }
    }
    // If no path is found suggest the default one.
    elseif ($library_path == NULL) {
      $library_path = IMAGEFIELD_CYCLE_JQUERYCYCLE_PATH;
    }
  }

  return $library_path;
}

/**
 * Return the version of JQuery Cycle that is installed
 */
function imagefield_cycle_get_jquery_cycle_version($filepath) {
  $version = 0;
  $pattern = '# * Version: ([0-9\.]+) \((.+)\)#';

  $js_contents = file_get_contents($filepath);
  if (preg_match($pattern, $js_contents, $matches)) {
    $version = $matches[1];
  }

  return $version;
}
