<?php

/**
 * @file imagefield_cycle.features.inc
 * Contains the implementions to enable Features Exportable settings
 */


/**
 * Implementation of hook_features_export().
 */
function imagefield_cycle_profile_features_export($data, &$export, $module_name) {
  $pipe = array();

  foreach ($data as $profile) {
    if ($settings = imagefield_cycle_get_settings($profile)) {
      $export['features']['imagefield_cycle_profile'][$profile] = $profile;
      $pipe['imagecache'][] = $settings['large_imagecache_preset'];
      $pipe['imagecache'][] = $settings['thumbnail_imagecache_preset'];
    }
  }

  $export['dependencies'] += array(
    'features' => 'features',
    'imagefield' => 'imagefield',
    'imageapi' => 'imageapi',
    'imagecache' => 'imagecache',
    'librares' => 'libraries',
  );

  // For each enabled Imagefield Cycle API, check if any need to alter the
  // feature, for example Lightbox2 needs to add any enabled imagecache preset
  // and add a dependency - Features internal component pipe alter does not
  // allow altering of the export dependencies, hence needing an internal hook.
  foreach (imagefield_cycle_get_module_apis() as $module => $info) {
    $function = $module .'_imagefield_cycle_profile_features_export';
    if (function_exists($function)) {
      $function($pipe, $data, $export, $module_name);
    }
  }

  return $pipe;
}


/**
 * Implementation of hook_features_export_options().
 */
function imagefield_cycle_profile_features_export_options() {
  $options = array();
  foreach (imagefield_cycle_get_settings() as $profile) {
    $options[$profile['name']] = $profile['name'];
  }
  return $options;
}


/**
 * Implementation of hook_features_export_options_render().
 */
function imagefield_cycle_profile_features_export_render($module_name, $data) {
  $items = array();

  foreach ($data as $name) {
    $preset = imagefield_cycle_get_settings($name);
    _features_sanitize($preset);
    $items[$name] = $preset;
  }

  $code = '  return '. features_var_export($items, '  ') .";\n";
  return array('imagefield_cycle_default_profiles' => $code);
}


/**
 * Implementation of hook_features_revert().
 */
function imagefield_cycle_profile_features_revert($module) {
  // Get the settings for the Feature module
  $profiles = module_invoke($module, 'imagefield_cycle_default_profiles');

  // For each profile, if there are any, delete any overriden settings
  if (!empty($profiles)) {
    foreach ($profiles as $profile) {
      db_query("DELETE FROM {imagefield_cycle_profiles} WHERE name = '%s'", $profile['name']);
    }
  }

  // Reset the cache
  imagefield_cycle_get_settings(NULL, TRUE);
}
