<?php

/**
 * @file lightbox2.imagefield_cycle.inc
 * This include contains any bridge-functionality to integrate Imagefield Cycle
 * with Lightbox2
 */


/**
 * Implementation of hook_imagefield_cycle_settings().
 */
function lightbox2_imagefield_cycle_settings(&$form, $profile) {
  $options = array('0' => t('-- Disabled --'));
  foreach (imagecache_presets() as $preset) {
    $options[$preset['presetname']] = $preset['presetname'];
  }

  $form['lightbox2_preset'] = array(
    '#type' => 'select',
    '#title' => t('Enable Lightbox2 on large image'),
    '#description' => t('If checked, the large image will appear using the following Imagecache preset when clicked'),
    '#options' => $options,
    '#default_value' => isset($profile['lightbox2_preset']) ? $profile['lightbox2_preset'] : '',
  );
}


/**
 * Implementation of hook_imagefield_cycle_theme_alter().
 */
function lightbox2_imagefield_cycle_theme_alter(&$theme) {
  $theme['lightbox2_imagefield_cycle_image'] = array(
    'arguments' => array('image_data' => NULL, 'element' => NULL, 'profile' => NULL, 'key' => NULL),
    'file' => 'modules/lightbox2.imagefield_cycle.inc',
  );
}


/**
 * Theme function for handling Lightbox output
 */
function theme_lightbox2_imagefield_cycle_image($image_data, $element, $profile, $key) {
  $item = $element[$key]['#item'];
  $item['data']['description'] = '';

  $node = $element['#node'];

  $field_name = $element['#field_name'];

  $args = array(
    'lightbox_preset' => $profile['lightbox2_preset'],
  );

  return theme('imagefield_image_imagecache_lightbox2', $image_data['presetname'], $field_name, $item, $node, 'lightbox', $args);
}


/**
 * Implementation of hook_imagefield_cycle_gallery_data_alter().
 */
function lightbox2_imagefield_cycle_gallery_data_alter(&$gallery_data, $profile) {
  if (!isset($profile['lightbox2_preset']) || !$profile['lightbox2_preset']) {
    return;
  }

  lightbox2_add_files();
  foreach ($gallery_data as $k => $v) {
    $gallery_data[$k]['large']['attributes']['rel'] = 'lightbox';
    $gallery_data[$k]['large']['handler'] = 'lightbox2_imagefield_cycle_image';
  }
}


/**
 * Custom internal hook - unfortunately, hook_features_pipe_COMPONENT_alter()
 * doesn't allow altering of the $export...
 */
function lightbox2_imagefield_cycle_profile_features_export(&$pipe, $data, &$export, $module_name) {
  // For each profile...
  foreach ($data as $profile) {
    // ... Get the profile settings
    if ($settings = imagefield_cycle_get_settings($profile)) {
      // Check if this profile has a lightbox2 imagecache preset enabled
      if (isset($settings['lightbox2_preset']) && !empty($settings['lightbox2_preset'])) {
        // If we get here then we have a profile which is Lightbox2 enabled
        // Add the preset name to the imagecache list
        $pipe['imagecache'][] = $settings['lightbox2_preset'];

        $export['dependencies']['lightbox2'] = 'lightbox2';
      }
    }
  }
}
